package de.ozgcloud.eingang.xdomea;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.nio.charset.StandardCharsets;

import org.apache.commons.io.IOUtils;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.ValueSource;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import de.ozgcloud.common.test.TestUtils;
import de.ozgcloud.eingang.common.formdata.IncomingFile;
import lombok.SneakyThrows;

class XdomeaXMLValueReaderTest {
	private static final String XML_FILE_NAME = "file.xml";
	private static final String PDF_FILE_NAME = "file.pdf";
	private static final String XML_ATTACHMENT_FILE_NAME = "saml-attachment-file.xml";

	@Spy
	@InjectMocks
	private XdomeaXMLValueReader valueReader;

	@DisplayName("read representation file names")
	@Nested
	class TestReadRepresentationFileNames {

		@Mock
		IncomingFile incomingXmlFile;

		@DisplayName("should find 'Dateiname' elements and all XML-files in MSR mantelantrag")
		@ParameterizedTest
		@ValueSource(strings = {
				"xdomea/mantelantrag_Geschaeftsgang.Geschaeftsgang.0201.xml",
				"xdomea/dfoerdermittel_Geschaeftsgang.Geschaeftsgang.0201.xml"
		})
		@SneakyThrows
		void shouldFindDateinameElements(String antragXMLFilename) {
			var xmlString = TestUtils.loadTextFile(
					antragXMLFilename,
					XML_FILE_NAME + "\n",
					PDF_FILE_NAME,
					"\n" + XML_ATTACHMENT_FILE_NAME + "\n");
			when(incomingXmlFile.getContentStream()).thenReturn(IOUtils.toInputStream(xmlString, StandardCharsets.UTF_8));

			var names = valueReader.readRepresentationFileNames(incomingXmlFile);

			assertThat(names).containsExactly(XML_FILE_NAME, PDF_FILE_NAME, XML_ATTACHMENT_FILE_NAME);
		}

	}

}
